==> goose-0.14.0.crate: goose-0.14.0/src/docs/goose-book/src/SUMMARY.md <==
# The Goose Book

[What Is Goose?](title-page.md)
[Requirements](requirements.md)

- [Getting Started](getting-started/overview.md)
    - [Creating A Load test](getting-started/creating.md)
    - [Running A Load Test](getting-started/running.md)
    - [Run-Time Options](getting-started/runtime-options.md)
        - [Common Options](getting-started/common.md)
        - [Throttle](getting-started/throttle.md)
    - [Metrics](getting-started/metrics.md)
    - [Tips](getting-started/tips.md)

- [Logging](logging/overview.md)
    - [Request Log](logging/requests.md)
    - [Task Log](logging/tasks.md)
    - [Error Log](logging/errors.md)
    - [Debug Log](logging/debug.md)

- [Controllers](controller/overview.md)
    - [Telnet Controller](controller/telnet.md)
    - [WebSocket Controller](controller/websocket.md)

- [Gaggle: Distributed Load Test](gaggle/overview.md)
    - [Manager](gaggle/manager.md)
    - [Worker](gaggle/worker.md)
    - [Configuration](gaggle/config.md)
    - [Technical details](gaggle/technical.md)

- [Coordinated Omission](coordinated-omission/overview.md)
    - [Mitigation](coordinated-omission/mitigation.md)
    - [Metrics](coordinated-omission/metrics.md)

- [Configuration](config/overview.md)
    - [Defaults](config/defaults.md)
    - [Scheduling Users And Tasks](config/scheduler.md)
    - [RustLS](config/rustls.md)

- [Examples](example/overview.md)
    - [Simple](example/simple.md)
    - [Simple Closure](example/simple-closure.md)
    - [Simple Session](example/simple-session.md)
    - [Drupal Memcache](example/drupal-memcache.md)
    - [Umami](example/umami.md)

==> goose-0.15.1.crate: goose-0.15.1/src/docs/goose-book/src/SUMMARY.md <==
# The Goose Book

[What Is Goose?](title-page.md)
[Requirements](requirements.md)

- [Getting Started](getting-started/overview.md)
    - [Creating A Load test](getting-started/creating.md)
    - [Running A Load Test](getting-started/running.md)
    - [Run-Time Options](getting-started/runtime-options.md)
        - [Common Options](getting-started/common.md)
        - [Throttle](getting-started/throttle.md)
    - [Metrics](getting-started/metrics.md)
    - [Tips](getting-started/tips.md)

- [Logging](logging/overview.md)
    - [Request Log](logging/requests.md)
    - [Task Log](logging/tasks.md)
    - [Error Log](logging/errors.md)
    - [Debug Log](logging/debug.md)

- [Controllers](controller/overview.md)
    - [Telnet Controller](controller/telnet.md)
    - [WebSocket Controller](controller/websocket.md)

- [Gaggle: Distributed Load Test](gaggle/overview.md)
    - [Manager](gaggle/manager.md)
    - [Worker](gaggle/worker.md)
    - [Configuration](gaggle/config.md)
    - [Technical details](gaggle/technical.md)

- [Coordinated Omission](coordinated-omission/overview.md)
    - [Mitigation](coordinated-omission/mitigation.md)
    - [Metrics](coordinated-omission/metrics.md)

- [Configuration](config/overview.md)
    - [Defaults](config/defaults.md)
    - [Scheduling Users And Tasks](config/scheduler.md)
    - [RustLS](config/rustls.md)

- [Examples](example/overview.md)
    - [Simple](example/simple.md)
    - [Closure](example/closure.md)
    - [Session](example/session.md)
    - [Drupal Memcache](example/drupal-memcache.md)
    - [Umami](example/umami.md)
